Wikipedia character sets
------------------------

This directory contains pages from https://en.wikipedia.org.

Wikipedia content is available under the CC BY-SA 3.0 licence, see https://en.wikipedia.org/wiki/Wikipedia:Text_of_Creative_Commons_Attribution-ShareAlike_3.0_Unported_License.
